summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Menzel <pmenzel@molgen.mpg.de>2022-02-21 22:40:41 +0100
committerPaul Menzel <pmenzel@molgen.mpg.de>2022-03-02 08:19:06 +0100
commitb69cbef7a83eadb102a1ff6c6f6fc5abce34805a (patch)
treebd74d9769dd5848948b22b61876ef656479ad97e
parent0914618b553d6f3366e568409cebf2656891ca69 (diff)
downloadacpica-b69cbef7a83eadb102a1ff6c6f6fc5abce34805a.tar.gz
executer/exsystem: Add units to time variable names
`HowLong` refers to different units in both functions, so make it more clear, what unit they expect. That also makes one comment superfluous.
-rw-r--r--source/components/executer/exsystem.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/source/components/executer/exsystem.c b/source/components/executer/exsystem.c
index 9e1e530a4..aafef2053 100644
--- a/source/components/executer/exsystem.c
+++ b/source/components/executer/exsystem.c
@@ -265,7 +265,7 @@ AcpiExSystemWaitMutex (
*
* FUNCTION: AcpiExSystemDoStall
*
* PARAMETERS: HowLong - The amount of time to stall,
* in microseconds
*
* RETURN: Status
@@ -280,7 +280,7 @@ AcpiExSystemWaitMutex (
ACPI_STATUS
AcpiExSystemDoStall (
- UINT32 HowLong)
+ UINT32 HowLongUs)
{
ACPI_STATUS Status = AE_OK;
@@ -288,21 +288,21 @@ AcpiExSystemDoStall (
ACPI_FUNCTION_ENTRY ();
- if (HowLong > 255) /* 255 microseconds */
+ if (HowLongUs > 255)
{
/*
- * Longer than 255 usec, this is an error
+ * Longer than 255 microseconds, this is an error
*
* (ACPI specifies 100 usec as max, but this gives some slack in
* order to support existing BIOSs)
*/
ACPI_ERROR ((AE_INFO,
- "Time parameter is too large (%u)", HowLong));
+ "Time parameter is too large (%u)", HowLongUs));
Status = AE_AML_OPERAND_VALUE;
}
else
{
- AcpiOsStall (HowLong);
+ AcpiOsStall (HowLongUs);
}
return (Status);
@@ -313,7 +313,7 @@ AcpiExSystemDoStall (
*
* FUNCTION: AcpiExSystemDoSleep
*
* PARAMETERS: HowLong - The amount of time to sleep,
* in milliseconds
*
* RETURN: None
@@ -324,7 +324,7 @@ AcpiExSystemDoStall (
ACPI_STATUS
AcpiExSystemDoSleep (
- UINT64 HowLong)
+ UINT64 HowLongMs)
{
ACPI_FUNCTION_ENTRY ();
@@ -337,12 +337,12 @@ AcpiExSystemDoSleep (
* For compatibility with other ACPI implementations and to prevent
* accidental deep sleeps, limit the sleep time to something reasonable.
*/
- if (HowLong > ACPI_MAX_SLEEP)
+ if (HowLongMs > ACPI_MAX_SLEEP)
{
- HowLong = ACPI_MAX_SLEEP;
+ HowLongMs = ACPI_MAX_SLEEP;
}
- AcpiOsSleep (HowLong);
+ AcpiOsSleep (HowLongMs);
/* And now we must get the interpreter again */
@@ -265,7 +265,7 @@ AcpiExSystemWaitMutex (
* FUNCTION: AcpiExSystemDoStall
*
- * PARAMETERS: HowLong - The amount of time to stall,
+ * PARAMETERS: HowLongUs - The amount of time to stall,
* in microseconds
*
@@ -313,7 +313,7 @@ AcpiExSystemDoStall (
* FUNCTION: AcpiExSystemDoSleep
*
- * PARAMETERS: HowLong - The amount of time to sleep,
+ * PARAMETERS: HowLongMs - The amount of time to sleep,
* in milliseconds
*